#### Building instructions.
#
### Overview of rebuild options:
#
# --without userland		: Build without the userland-package (default: with it)
# --without modules		: Build without the kernel-module-package (default: with it)
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different Fedora kernel.  
#
### Examples:
#
## To rebuild whole package for the running kernel:
#
# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running Fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, Fedora kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.


%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}
%define     x11libdir         %{_prefix}/X11R6/%{_lib}
%define     x11libdir32bit    %{_prefix}/X11R6/lib
%define     nvidialibdir      %{_libdir}/nvidia
%define     nvidialibdir32bit %{_prefix}/lib/nvidia
%define     modpath           kernel/drivers/video/nvidia

Name:       nvidia-glx
Version:    1.0.7676
Release:    0.SL.1
Epoch:      0
License:    Distributable
URL:        http://www.nvidia.com/
Group:      System Environment/Libraries
Summary:    Nvidia Display Driver and OpenGL libraries
Source0:    ftp://download.nvidia.com/XFree86/Linux-x86/1.0-7676/NVIDIA-Linux-x86-1.0-7676-pkg0.run
Source1:    ftp://download.nvidia.com/XFree86/Linux-x86_64/1.0-7676/NVIDIA-Linux-x86_64-1.0-7676-pkg2.run
Source2:    nvidia-glx.sh
Source3:    nvidia-glx.csh
Source4:    nvidia-settings.desktop
Source5:    nvidia-glx-init
Source10:   nvidia-config-display
Source11:   nvidia-README.Fedora
Patch0:     nvidia-driver-no-ldconfig.patch
Patch1:     nvidia-driver-no-kernel-module-install.patch
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Conflicts:  nvidia-glx-legacy
Requires:   pyxf86config
Requires:   kernel-module-nvidia = %{epoch}:%{version}
Requires(post):  chkconfig ldconfig
Requires(preun): chkconfig
BuildRequires:  desktop-file-utils 
ExclusiveArch:	%{ix86} x86_64


%description 
This package provides Nvidia hardware accelerated OpenGL support
for Nvidia chipsets from Gefore2, Quadro4 or newer.


%package -n kernel-module-nvidia-%{kernel}
Summary:    Nvidia Display Driver
Group:      System Environment/Kernel
Provides:   kernel-module-nvidia = %{epoch}:%{version}-%{release}
Conflicts:  kernel-module-nvidia-legacy-%{kernel}
Requires:   nvidia-glx = %{epoch}:%{version}
Requires(post):   %{_sbindir}/nvidia-config-display modutils
Requires(postun): modutils
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  kernel-devel-%{_target_cpu} = %{kernel}
%endif
%endif
Requires:   modutils

%description -n kernel-module-nvidia-%{kernel}
This is Nvidia's graphics driver for linux-x86 computers. Currently
only x86 arch's are supported. This package is build for 
kernel %{?kernel} built for %{_target_cpu}

%package devel
Summary:    Nvidia OpenGL Headers
Group:      Development/Libraries
Requires:   nvidia-glx = %{epoch}:%{version}-%{release}

%description devel
This package provides Nvidia OpenGL header files required for
development. The headers are installed in %{_includedir}/nvidia.

%prep
%setup -c -T
%ifarch %{ix86}
sh %{SOURCE0} --extract-only --target nvidiapkg
%else
sh %{SOURCE1} --extract-only --target nvidiapkg
%endif

pushd nvidiapkg
# Dont run ldconfig
%patch0 -p0 -b .ldconfig
%patch1 -p0 -b .makeinstall
popd

%if 0%{!?_without_modules:1}
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
%endif     #!?_without_modules:1


%build
%if 0%{!?_without_modules:1}
pushd nvidiapkg/usr/src/nv
ln -s -f Makefile.kbuild Makefile
make SYSSRC="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" module
popd
%endif     #!?_without_modules:1


%install
rm -rf $RPM_BUILD_ROOT ./__doc
%if 0%{!?_without_userland:1}
mkdir -p \
    $RPM_BUILD_ROOT%{x11libdir}/modules/drivers \
    $RPM_BUILD_ROOT%{x11libdir}/modules/extensions/nvidia \
    $RPM_BUILD_ROOT%{x11libdir}/tls \
    $RPM_BUILD_ROOT%{_libdir}/tls \
    $RPM_BUILD_ROOT%{nvidialibdir}/tls \
    $RPM_BUILD_ROOT%{_includedir} 

make install INSTALL_TLS=1 -C nvidiapkg \
    ROOT=$RPM_BUILD_ROOT DOCDIR=$(pwd)/__doc

# OpenGL libraries
mv \
    $RPM_BUILD_ROOT/%{_libdir}/libGL* \
    $RPM_BUILD_ROOT/%{_libdir}/libnvidia-tls.so.%{version} \
    $RPM_BUILD_ROOT/%{nvidialibdir}
mv  $RPM_BUILD_ROOT/%{_libdir}/tls/libnvidia-tls.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/tls
ln -s libGLcore.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/libGLcore.so
ln -s libGLcore.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/libGLcore.so.1
ln -s libGL.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/libGL.so.1 
ln -s libnvidia-tls.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/libnvidia-tls.so.1
ln -s libnvidia-tls.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir}/tls/libnvidia-tls.so.1

# 32-bit libs on x86_64
%ifarch x86_64
mkdir -p \
    $RPM_BUILD_ROOT%{x11libdir32bit}/ \
    $RPM_BUILD_ROOT%{nvidialibdir32bit}/ \
    $RPM_BUILD_ROOT%{nvidialibdir32bit}/tls
install -m 0755 nvidiapkg/usr/lib32/libGLcore.so.%{version} $RPM_BUILD_ROOT%{nvidialibdir32bit}/
install -m 0755 nvidiapkg/usr/lib32/libGL.so.%{version} $RPM_BUILD_ROOT%{nvidialibdir32bit}/
install -m 0755 nvidiapkg/usr/lib32/libnvidia-tls.so.%{version} $RPM_BUILD_ROOT%{nvidialibdir32bit}/
install -m 0755 nvidiapkg/usr/lib32/tls/libnvidia-tls.so.%{version} $RPM_BUILD_ROOT%{nvidialibdir32bit}/tls/
ln -s libGLcore.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir32bit}/libGLcore.so
ln -s libGLcore.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir32bit}/libGLcore.so.1
ln -s libGL.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir32bit}/libGL.so.1 
ln -s libnvidia-tls.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir32bit}/libnvidia-tls.so.1
ln -s libnvidia-tls.so.%{version} $RPM_BUILD_ROOT/%{nvidialibdir32bit}/tls/libnvidia-tls.so.1
%endif # x86_64

# Move extension in nvidia subdirectory
mv $RPM_BUILD_ROOT%{x11libdir}/modules/extensions/libglx.so* $RPM_BUILD_ROOT%{x11libdir}/modules/extensions/nvidia

# Add XvMC symlink
ln -s libXvMCNVIDIA.so.%{version} $RPM_BUILD_ROOT%{x11libdir}/libXvMCNVIDIA_dynamic.so.1

# profile.d files
install -D -m 0755 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/nvidia-glx.sh
install -D -m 0755 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/nvidia-glx.csh

# X configuration script
install -D -m 0755 %{SOURCE10} $RPM_BUILD_ROOT%{_sbindir}/nvidia-config-display

# Control panel
install -D -m 0755 nvidiapkg/usr/bin/nvidia-settings $RPM_BUILD_ROOT%{_bindir}/nvidia-settings

# Desktop entry for nvidia-settings
desktop-file-install --vendor livna \
    --dir $RPM_BUILD_ROOT%{_datadir}/applications/ \
    --add-category X-Livna \
    --add-category Application \
    --add-category System \
    %{SOURCE4}

# Install initscript
install -D -m 0755 %{SOURCE5} $RPM_BUILD_ROOT%{_initrddir}/nvidia-glx

# OpenGL headers
mv __doc/include $RPM_BUILD_ROOT%{_includedir}/nvidia

# More docs
cp %{SOURCE11} __doc/README.Fedora
cp nvidiapkg/LICENSE __doc/

# ld.so.conf.d file
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/
echo "%{nvidialibdir}" > $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/nvidia-glx.conf
%ifarch x86_64
echo "%{nvidialibdir32bit}" >> $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/nvidia-glx.conf
%endif

# Workaround FC-Bug 151527 (part1):
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/udev/devices/
touch $(seq -f "$RPM_BUILD_ROOT%{_sysconfdir}/udev/devices/nvidia%g" 0 3)
touch $RPM_BUILD_ROOT%{_sysconfdir}/udev/devices/nvidiactl

%endif     #!?_without_userland:1


%if 0%{!?_without_modules:1}
# Kernel module
install -D -m 0644 nvidiapkg/usr/src/nv/nvidia.ko $RPM_BUILD_ROOT/lib/modules/%{kernel}/%{modpath}/nvidia.ko
%endif     #!?_without_modules:1


%clean
rm -rf $RPM_BUILD_ROOT


%pre -n nvidia-glx
# Get rid of all these, previous versions have left 256 device files here
if [ -e /etc/udev/devices/nvidia4 ] ; then
    rm -rf /etc/udev/devices/nvidia* || :
fi
# Upgrade on FC2. Make sure ld.so.conf doesn't contain our dir (ld.so.conf.d is used instead)
if grep "%{nvidialibdir}" %{_sysconfdir}/ld.so.conf &> /dev/null ; then
    mv %{_sysconfdir}/ld.so.conf %{_sysconfdir}/ld.so.conf.backup-nvidia-glx1
    grep -v "%{nvidialibdir}" %{_sysconfdir}/ld.so.conf.backup-nvidia-glx1 2> /dev/null > %{_sysconfdir}/ld.so.conf 
fi
# Stolen from the ati-fglrx spec file by Thorsten Leemhuis  
# We want to choose and load fglrx libGL before X11/system libGL
if ! grep -v -m 1 -e '/usr/X11R6/lib/' /etc/ld.so.conf | grep -e '^include ld.so.conf.d/\*.conf' &>/dev/null ; then
    # Add ld.so.conf.d include entry in the first line
    /bin/grep -v -e '^include ld.so.conf.d/\*.conf' %{_sysconfdir}/ld.so.conf > %{_sysconfdir}/ld.so.conf.backup-nvidia-glx
    /bin/echo 'include ld.so.conf.d/*.conf' > %{_sysconfdir}/ld.so.conf
    /bin/cat %{_sysconfdir}/ld.so.conf.backup-nvidia-glx >> %{_sysconfdir}/ld.so.conf
fi
# End of stolen

%post -n nvidia-glx
# Workaround FC-Bug 151527 (part2):
cp -a /dev/nvidia[0-3] /dev/nvidiactl /etc/udev/devices/  ||:
/sbin/ldconfig 
# We changed the point when the init-scipt is called in 1.0.7176-0.lvn.2
# So del and readd the script with chkconfig
/sbin/chkconfig --del nvidia-glx ||:
/sbin/chkconfig --add nvidia-glx ||:
echo "alias char-major-195* nvidia" >> %{_sysconfdir}/modprobe.conf
echo "options nvidia NVreg_ModifyDeviceFiles=0" >> %{_sysconfdir}/modprobe.conf


%preun -n nvidia-glx
if [ "$1" -eq "0" ]; then  
    # Disable driver on final removal
    %{_initrddir}/nvidia-glx stop &>/dev/null
    test -f %{_sbindir}/nvidia-config-display && %{_sbindir}/nvidia-config-display disable ||:
    /sbin/chkconfig --del nvidia-glx ||:
fi ||:
# Remove all entries of nvidia/NVdriver from modprobe.conf
if [ -f %{_sysconfdir}/modprobe.conf.backup-nvidia-glx ]; then
  # Make a backup of the backup
  mv %{_sysconfdir}/modprobe.conf.backup-nvidia-glx %{_sysconfdir}/modprobe.conf.backup-nvidia-glx-old
fi
mv %{_sysconfdir}/modprobe.conf %{_sysconfdir}/modprobe.conf.backup-nvidia-glx
grep -v -E -e "^alias +[^ ]+ +(nvidia|NVdriver)" -e "options nvidia " %{_sysconfdir}/modprobe.conf.backup-nvidia-glx > %{_sysconfdir}/modprobe.conf


%postun -n nvidia-glx -p /sbin/ldconfig


%post -n kernel-module-nvidia-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  depmod -a >/dev/null || :
fi
%endif
# Enable Nvidia driver if running kernel
if [ "$(uname -r)" = "%{kernel}" ] ; then
    test -f %{_sbindir}/nvidia-config-display && %{_sbindir}/nvidia-config-display enable ||:
fi ||:


%postun -n kernel-module-nvidia-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%if 0%{!?_without_modules:1}
%files -n kernel-module-nvidia-%{kernel}
%defattr(0744,root,root,0755)
%dir /lib/modules/%{kernel}/%{modpath}
/lib/modules/%{kernel}/%{modpath}/nvidia.ko
%endif     #!?_without_modules:1


%if 0%{!?_without_userland:1}
%files -n nvidia-glx
%defattr(-,root,root,-)
%doc __doc/*
%dir %{nvidialibdir}
%dir %{nvidialibdir}/tls
%dir %{x11libdir}/modules/extensions/nvidia
%dir %{_initrddir}/nvidia-glx
%dir %{_includedir}/nvidia/GL
%{_includedir}/nvidia/GL/*
%{nvidialibdir}/*.so.*
%{nvidialibdir}/tls/*.so.*
%{_sbindir}/nvidia-config-display
%{_sysconfdir}/profile.d/nvidia*
%{x11libdir}/libXvMCNVIDIA*.so.*
%{x11libdir}/modules/drivers/nvidia_drv.o
%{x11libdir}/modules/extensions/nvidia/*
%{_bindir}/nvidia-settings
%{_datadir}/applications/*nvidia-settings.desktop
%config %{_sysconfdir}/ld.so.conf.d/nvidia-glx.conf
%attr(0600,root,root) %dev(c,195,0) /dev/nvidia0
%attr(0600,root,root) %dev(c,195,1) /dev/nvidia1
%attr(0600,root,root) %dev(c,195,2) /dev/nvidia2
%attr(0600,root,root) %dev(c,195,3) /dev/nvidia3
%attr(0600,root,root) %dev(c,195,255) /dev/nvidiactl
# Workaround FC-Bug 151527 (part3):
#attr(0600,root,root) %dev(c,195,0) %{_sysconfdir}/udev/devices/nvidia0
#attr(0600,root,root) %dev(c,195,1) %{_sysconfdir}/udev/devices/nvidia1
#attr(0600,root,root) %dev(c,195,2) %{_sysconfdir}/udev/devices/nvidia2
#attr(0600,root,root) %dev(c,195,3) %{_sysconfdir}/udev/devices/nvidia3
#attr(0600,root,root) %dev(c,195,255) %{_sysconfdir}/udev/devices/nvidiactl
%ghost %{_sysconfdir}/udev/devices/nvidia0
%ghost %{_sysconfdir}/udev/devices/nvidia1
%ghost %{_sysconfdir}/udev/devices/nvidia2
%ghost %{_sysconfdir}/udev/devices/nvidia3
%ghost %{_sysconfdir}/udev/devices/nvidiactl
%ifarch x86_64
%dir %{nvidialibdir32bit}
%dir %{nvidialibdir32bit}/tls
%{nvidialibdir32bit}/*.so.*
%{nvidialibdir32bit}/tls/*.so.*
%endif  #x86_64


%files devel
%defattr(-,root,root,-)
%{_includedir}/nvidia
%{nvidialibdir}/*.so
%{x11libdir}/libXvMCNVIDIA.a
%ifarch x86_64
%{nvidialibdir32bit}/*.so
%endif #x86_64

%endif     #!?_without_userland:1

%changelog
* Sun Sep 04 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:1.0.7176-0.lvn.3
- Conflics with nvidia-glx-legacy
- Integrate some minor correction suggested by Niko Mirthes 
  <nmirthes AT gmail DOT com> in #475

* Fri Aug 26 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:1.0.7176-0.lvn.2
- Rename src5: nvidia.init to nvidia-glx-init
- Fix correct servicename in nvidia-glx-init
- Run nvidia-glx-init before gdm-early-login; del and readd the script
  during post

* Sun Aug 21 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:1.0.7176-0.lvn.1
- Update to 7676
- Lots of cleanup from me and Niko Mirthes <nmirthes AT gmail DOT com>
- add NVreg_ModifyDeviceFiles=0 to modprobe.conf (Niko)
- Drop support for FC2
- Nearly proper Udev-Support with workarounds around FC-Bug 151527

* Fri Jun 17 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7174-0.lvn.5
- Slight change of modprobe.conf rexexp

* Thu Jun 16 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7174-0.lvn.4
- Fixed a critical bug in modprobe.conf editing where all lines starting with alias and 
  ending with then a word starting with any of the letters n,v,i,d,i,a,N,V,r,e is removed.

* Mon Jun 13 2005 Thorsten Leemhuis <fedora AT leemhuis DOT info> - 0:1.0.7174-0.lvn.3
- Adjust kenrnel-module-stuff for FC4
- Ship both x86 and x64 in the SRPM

* Sun Jun 12 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7174-0.lvn.2
- Only create 16 devices
- Put libXvMCNVIDIA.a in -devel
- Don't remove nvidia options in /etc/modprobe.conf
- Make ld.so.conf file config(noreplace)
- Use same directory permissions as the kernel

* Sat Apr 2 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7174-0.lvn.1
- New upstream release, 7174

* Wed Mar 30 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7167-0.lvn.5
- Added x86_64 support patch from Thorsten Leemhuis

* Wed Mar 23 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7167-0.lvn.4
- Fix kernel module permissions again (644)
- Only create 16 /dev/nvidia* devices, 256 is unnecessary

* Fri Mar 18 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7167-0.lvn.3
- Fixed kernel-module permissions

* Thu Mar 17 2005 Dams <anvil[AT]livna.org> 0:1.0.7167-0.lvn.2
- Removed provides on kernel-module and kernel-modules

* Sat Mar 05 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.7167-0.lvn.1
- New upstream release 1.0.7167
- Added patch from http://www.nvnews.net/vbulletin/showthread.php?t=47405
- Removed old patch against 2.6.9

* Sat Feb 05 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6629-0.lvn.7
- Added a number of post-6629 patches from http://www.minion.de/files/1.0-6629
- Fixed permissions of nvidia/nvidia.ko

* Fri Jan 21 2005 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6629-0.lvn.6
- Fix incorrect MAKDEV behaviour and dependency

* Tue Nov 30 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6629-0.lvn.4
- Fixed creation of /dev/nvidia* on FC2

* Sat Nov 27 2004 Dams <anvil[AT]livna.org> - 0:1.0.6629-0.lvn.3
- Dont try to print kvariant in description when it's not defined.

* Sun Nov 21 2004 Thorsten Leemhuis <fedora at leemhuis dot info> - 0:1.0.6629-0.lvn.2
- resulting kernel-module package now depends again on /root/vmlinuz-<kernelver>
- Use rpmbuildtags driverp and kernelp

* Sat Nov 06 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6629-0.lvn.1
- New upstream version, 1.0-6629
- Build without kernel-module-devel by default

* Fri Oct 29 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6111-0.lvn.6
- Make n-c-display handle misc problems in a better way
- Fixed wrong icon file name in .desktop file
- Re-added the mysteriously vanished sleep line in the init script
  when kernel module wasn't present

* Fri Oct 22 2004 Thorsten Leemhuis <fedora at leemhuis dot info> - 0:1.0.6111-0.lvn.5
- Use fedora-kmodhelper in the way ntfs or ati-fglrx use it
- Allow rpm to strip the kernel module. Does not safe that much space ATM but
  might be a good idea
- Allow to build driver and kernel-module packages independent of each other
- Some minor spec-file changes

* Thu Oct 21 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6111-0.lvn.4
- udev fixes
- Incorporated fix for missing include line in ld.so.conf from ati-fglrx spec (T Leemhuis)

* Sun Sep 19 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6111-0.lvn.3
- Remove FC1/kernel 2.4 compability
- Rename srpm to nvidia-glx
- Build with kernel-module-devel

* Sun Aug 15 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6111-0.lvn.2
- Restore ldsoconfd macro
- Disable autoamtic removal of scripted installation for now; needs testing

* Sat Aug 14 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6111-0.lvn.1
- Upstream release 6111
- Fixed init script (again)

* Tue Aug  3 2004 Dams <anvil[AT]livna.org> 0:1.0.6106-0.lvn.4
- ld.so.conf.d directory detected by spec file
- Using nvidialibdir in nvidia-glx-devel files section
- Got rid of yarrow and tettnang macros
- libGL.so.1 symlink in tls directory always present

* Mon Jul 19 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.3
- Fixed script bug that would empty prelink.conf
- Added symlink to non-tls libGL.so.1 on FC1  

* Tue Jul 13 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.2.3
- Updated init script to reflect name change -xfree86 -> -display  

* Mon Jul 12 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.2.2
- Fixed backup file naming

* Sun Jul 11 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.2.1
- Restore working macros 
- Always package the gui tool 

* Sun Jul 11 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.2
- Renamed nvidia-config-xfree86 to nvidia-config-display
- Fixed symlinks 
- Use ld.so.conf.d on FC2 
- Remove script installation in pre
- Use system-config-display icon for nvidia-settings
- 2 second delay in init script when kernel module not found
- Make nvidia-config-display fail more gracefully
- Add blacklist entry to prelink.conf on FC1

* Mon Jul 05 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.6106-0.lvn.1
- New upstream release
- First attempt to support FC2 
- Dropped dependency on XFree86

* Mon Feb 09 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.5336-0.lvn.3
- Use pkg0

* Sun Feb 08 2004 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.5336-0.lvn.2
- New Makefile variable SYSSRC to point to kernel sources.
- kmodhelper fixes.

* Fri Jan 30 2004 Keith G. Robertson-Turner <nvidia-devel[AT]genesis-x.nildram.co.uk> 0:1.0.5336-0.lvn.1
- New upstream release
- Removed (now obsolete) kernel-2.6 patch
- Install target changed upstream, from "nvidia.o" to "module"
- Linked nv/Makefile.kbuild to (now missing) nv/Makefile

* Sun Jan 25 2004 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.18
- Updated nvidia-config-display
- Now requiring pyxf86config

* Mon Jan 19 2004 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.17
- Added nvidiasettings macro to enable/disable gui packaging

* Mon Jan 19 2004 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.16
- Updated minion.de patches
- Added some explicit requires 
- Test nvidia-config-xfree86 presence in kernel-module package
  scriptlets

* Mon Jan 12 2004 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.15
- Updated Readme.fedora
- nvidia-glx-devel package

* Sat Jan  3 2004 Dams <anvil[AT]livna.org> 0:1.0.5328-0.lvn.14
- Hopefully fixed kernel variant thingy

* Fri Jan  2 2004 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.13
- Support for other kernel variants (bigmem, etc..)
- Changed URL in Source0

* Tue Dec 30 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.13
- Dropped nvidia pkgX information in release tag.

* Tue Dec 30 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.12.pkg0
- Renamed kernel module package in a kernel-module-nvidia-`uname -r` way
- Using fedora.us kmodhelper for kernel macro
- Using nvidia pkg0 archive

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.11.pkg1
- kernel-module-nvidia package provides kernel-module
- We wont own devices anymore. And we wont re-create them if they are
  already present

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.10.pkg1
- Yet another initscript update. Really.
- Scriptlets updated too

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.9.pkg1
- Fixed alias in modprobe.conf for 2.6

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.8.pkg1
- Another initscript update

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.7.pkg1
- kernel module requires kernel same kversion
- initscript updated again
- Dont conflict, nor obsolete XFree86-Mesa-libGL. Using ld.so.conf to
  make libGL from nvidia first found. Hope Mike Harris will appreciate.

* Sun Dec 21 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.6.pkg1
- kernel-module-nvidia requires kernel same version-release

* Sat Dec 20 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.6.pkg1
- Updated initscript

* Fri Dec 19 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.lvn.5.pkg1
- lvn repository tag

* Fri Dec 19 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.fdr.5.pkg1
- Added initscript to toggle nvidia driver according to running kernel
  and installed kernel-module-nvidia packages
- Updated scriptlets

* Thu Dec 18 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.fdr.4.pkg1
- Arch detection
- Url in patch0

* Tue Dec 16 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.fdr.3.pkg1
- Desktop entry for nvidia-settings
- s/kernel-module-{name}/kernel-module-nvidia
- nvidia-glx doesnt requires kernel-module-nvidia-driver anymore
- Using modprobe.conf for 2.6 kernel
- Hopefully fixed symlinks

* Mon Dec 15 2003 Dams <anvil[AT]livna.org> 0:1.0.4620-0.fdr.2.pkg1
- Building kernel module for defined kernel
- kernel module for 2.6 is nvidia.ko
- Patch not to install kernel module on make install
- Updated patch for 2.6
- depmod in scriptlet for defined kernel
- nvidia-glx conflicting XFree86-Mesa-libGL because we 0wn all its
  symlink now
- Dont override libGL.so symlink because it belongs to XFree86-devel
- Added nvidia 'pkgfoo' info to packages release
- Spec file cleanup

* Fri Dec 12 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4620-0.fdr.2
- Fixed repairing of a link in post-uninstall
- Obsolete Mesa instead of Conflict with it, enables automatic removal.

* Mon Dec 08 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4620-0.fdr.1
- Added support for 2.6 kernels
- Cleaned up build section, removed the need for patching Makefiles.
- Added missing BuildReq gcc32
- Don't package libs twice, only in /usr/lib/tls/nvidia
- Made config cript executable and put it into /usr/sbin
- Moved kernel module to kernel/drivers/video/nvidia/ 
- Fixed libGL.so and libGLcore.so.1 links to allow linking against OpenGL libraries

* Mon Dec 08 2003 Keith G. Robertson-Turner <nvidia-devel at genesis-x.nildram.co.uk> - 0:1.0.4620-0.fdr.0
- New beta 4620 driver
- New GUI control panel
- Some minor fixes

* Thu Nov 20 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.10.1
- Finally fixed SMP builds.

* Wed Nov 19 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.9
- Don't make nvidia-glx depend on kernel-smp

* Tue Nov 18 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.8
- Some build fixes

* Tue Nov 11 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.7
- Added CC=gcc32  
- Fixed upgrading issue
- Added driver switching capabilities to config script.

* Fri Nov 07 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.4
- Added conflict with XFree86-Mesa-libGL.
- Disabled showing of the README.Fedora after installation.

* Sun Oct 12 2003 Peter Backlund <peter dot backlund at home dot se> - 0:1.0.4496-0.fdr.3 
- Added NVidia configuration script written in Python.
- Some cleanup of files section
- For more info, see https://bugzilla.fedora.us/show_bug.cgi?id=402

* Tue Jul 08 2003 Andreas Bierfert (awjb) <andreas.bierfert[AT]awbsworld.de> - 0:1.0.4363-0.fdr.2
- renamed /sbin/makedevices.sh /sbin/nvidia-makedevices.sh ( noticed by 
  Panu Matilainen )
- Fixed name problem
* Sun Jun 22 2003 Andreas Bierfert (awjb) <andreas.bierfert[AT]awbsworld.de> - 0:1.0.4363-0.fdr.1
- Initial RPM release, still some ugly stuff in there but should work...
